@@ -15,7 +15,7 @@ use crate::constants::messages::APP_OPTIONS_NOT_FOUND;
 use crate::{config::clone::CloneAction, constants::patterns::GIT_URL};
 
 #[derive(Parser, Debug)]
-#[clap(name = "(Dev)mode", version = "0.2.6")]
+#[clap(name = "(Dev)mode", version = "0.2.7")]
 #[clap(author = "Eduardo F. <edfloreshz@gmail.com>")]
 #[clap(about = "Dev(mode) is a project management utility for developers.")]
 #[clap(setting(AppSettings::ArgRequiredElseHelp))]
@@ -275,7 +275,9 @@ pub fn config_owner() -> anyhow::Result<Settings> {
 pub fn config_host() -> anyhow::Result<Settings> {
     let answer = pick("host", "Choose your Git host:", vec!["GitHub", "GitLab"])?;
     let host = match answer {
-        Answer::String(host) => Host::from(&host).to_string(),
+        Answer::ListItem(item) => {
+            Host::from(&item.text).to_string()
+        },
         _ => bail!("Host is required."),
     };
     let current = Config::get::<Settings>("devmode/config/config.toml", FileType::TOML);
